@@ -21,6 +21,7 @@ class Base(object):
     _class_id__repr__: bool
     _id: str
     _id__repr__: bool
+    _verbose: bool
 
     def __init__(self, object_id: str) -> None:
         """
@@ -35,6 +36,7 @@ class Base(object):
         self._class_id__repr__ = False  # If True, repr/str of the object is class id
         self._id = object_id
         self._id__repr__ = False  # If True, repr/str of the object adds object id
+        self._verbose = True  # Enable verbose mode (errors/warnings)
 
     def __repr__(self) -> str:
         """
@@ -48,8 +50,7 @@ class Base(object):
         if self._class_id__repr__:
             return self.get_class_id()
         if self._id__repr__:
-            return sup_repr.replace(' object at ',
-                                    f'["{self.get_id()}"] object at ')
+            return sup_repr.replace(' object at ', f'["{self.get_id()}"] object at ')
         return sup_repr
 
     def _update__repr___(self, obj: 'Base') -> None:
